@@ -19,6 +19,7 @@ import lxml.html
 import magic
 
 from .utils import AMO_BASE, AMO_EDITOR_BASE, AMO_REVIEWERS_API_BASE, csspath
+from .user import User
 from .lzma import SevenZFile
 
 
@@ -53,6 +54,7 @@ class Review:
         self.slug = None
         self.api_token = None
         self.enabledversions = []
+        self.developers = []
 
     def find_latest_version(self):
         if len(self.versions) > 0:
@@ -80,12 +82,11 @@ class Review:
     def get_next_page(self):
         return self.get_version_page(self.page + 1)
 
-    def get_version_page(self, page=1):
-        req = self.session.get(self.url + "?page=%d" % page, stream=True, allow_redirects=False)
-
+    def check_redirects(self, req):
         if req.status_code == 302:
             if 'messages' not in req.cookies:
                 raise Exception("Invalid response")
+
             message = req.cookies['messages'].split("\\\\n")
             if len(message) != 4:
                 raise Exception("Invalid response")
@@ -99,6 +100,12 @@ class Review:
             else:
                 req.raise_for_status()
 
+        return req
+
+    def get_version_page(self, page=1):
+        req = self.session.get(self.url + "?page=%d" % page, stream=True, allow_redirects=False)
+        req = self.check_redirects(req)
+
         req.raw.decode_content = True
         doc = lxml.html.parse(req.raw).getroot()
 
@@ -109,12 +116,14 @@ class Review:
         self.enabledversions = [
           x.attrib['value'] for x in doc.xpath(csspath('#id_versions > option'))
         ]
-        tokennodes = doc.xpath(csspath("#extra-review-actions"))
-        self.api_token = tokennodes[0].attrib['data-api-token'] if tokennodes else None
 
         self.addonid = doc.xpath(csspath('#addon'))[0].attrib['data-id']
-        slugnodes = doc.xpath(csspath(".file-info > .light > a:not([title])"))
-        self.slug = unquote(slugnodes[0].attrib['href'].split("/")[-4])
+        try:
+            slugnodes = doc.xpath(csspath(".file-info > .light > a:not([title])"))
+            self.slug = unquote(slugnodes[0].attrib['href'].split("/")[-4])
+        except IndexError:
+            slugnodes = doc.xpath(csspath("#actions-addon > li > a[href$='/edit']"))
+            self.slug = unquote(slugnodes[0].attrib['href'].split("/")[-4])
 
         if self.unlisted:
             self.url = '%s/review-unlisted/%s' % (AMO_EDITOR_BASE, self.slug)
@@ -155,6 +164,14 @@ class Review:
             versions.append(AddonReviewVersion(self, head, head.getnext()))
 
         self.versions = versions + self.versions
+
+        devnodes = doc.xpath(
+          csspath('#scroll_sidebar ul:not([id]) a[href*="/user/"]')
+        )
+
+        for dev in devnodes:
+            self.developers.append(User.getcache(self.parent, dev.attrib['href'].split("/")[-2]))
+
         self.page = page
         return True
 
@@ -206,7 +223,7 @@ class Review:
 
     def flags(self, flags=None):
         url = AMO_REVIEWERS_API_BASE + '/addon/%s/flags/' % self.addonid
-        headers = {'Authorization': 'Bearer ' + self.api_token}
+        headers = {'Authorization': 'Session ' + self.session.cookies.get('sessionid')}
         req = self.session.patch(url, json=flags or {}, headers=headers, allow_redirects=False)
         print(req.json())
         if not req.status_code == 200:
@@ -215,7 +232,7 @@ class Review:
 
     def admin_disable(self):
         url = AMO_REVIEWERS_API_BASE + '/addon/%s/disable/' % self.addonid
-        headers = {'Authorization': 'Bearer ' + self.api_token}
+        headers = {'Authorization': 'Session ' + self.session.cookies.get('sessionid')}
         req = self.session.post(url, headers=headers, allow_redirects=False)
         return req.status_code == 202
 
@@ -236,7 +253,7 @@ class Review:
             "un" if not subscribe else "",
             "un" if self.unlisted else ""
         )
-        headers = {'Authorization': 'Bearer ' + self.api_token}
+        headers = {'Authorization': 'Session ' + self.session.cookies.get('sessionid')}
         req = self.session.post(url, headers=headers, allow_redirects=False)
         return req.status_code == 202
 
@@ -339,7 +356,7 @@ class AddonReviewVersion:
             elif mime == "application/zip":
                 with ZipFile(self.sourcepath, 'r') as zf:
                     zf.extractall(extractpath)
-            elif mime == "application/x-gzip":
+            elif mime in ('application/x-gzip', 'application/gzip'):
                 with tarfile.open(self.sourcepath, 'r:gz') as zf:
                     zf.extractall(extractpath)
             else:
@@ -368,6 +385,7 @@ class AddonVersionFile:
         'Mac OS X': 'mac',
         'Windows': 'windows',
         'All Platforms': 'all',
+        'Download': 'all',  # Themes
         'Android': 'android'
     }
 
@@ -395,7 +413,7 @@ class AddonVersionFile:
         urlpath = urlparse(self.url).path
         urlpathparts = urlpath.split('/')
         self.filename = urlpathparts[-1]
-        self.addonid = urlpathparts[-2]
+        self.fileid = urlpathparts[-3]
         self.savedpath = None
         self.profile = None
 
